==> members-facade-1.0.2-20190326.080455-67-sources.jar: com/bizvane/members/facade/models/po/MbrEuCurrencyRecordPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class MbrEuCurrencyRecordPO implements Serializable {

	/**
	 * 只读. 主键id 自增. mbr_eu_currency_record_id
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "主键id 自增", name = "mbrEuCurrencyRecordId", required = false, example = "")
	private Long mbrEuCurrencyRecordId;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. brand_id
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 会员code. member_code
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员code", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 北欧币余额. total_amount
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "北欧币余额", name = "totalAmount", required = false, example = "")
	private BigDecimal totalAmount;
	/**
	 * 只读. 流水数目. amount
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "流水数目", name = "amount", required = false, example = "")
	private BigDecimal amount;
	/**
	 * 只读. 订单号. order_no
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "订单号", name = "orderNo", required = false, example = "")
	private String orderNo;
	/**
	 * 只读. 下单时间. place_order_time
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "下单时间", name = "placeOrderTime", required = false, example = "")
	private Date placeOrderTime;
	/**
	 * 只读. 线下更新时间. offline_update_date
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线下更新时间", name = "offlineUpdateDate", required = false, example = "")
	private Date offlineUpdateDate;
	/**
	 * 只读. . offline_company_code
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "offlineCompanyCode", required = false, example = "")
	private String offlineCompanyCode;
	/**
	 * 只读. 品牌code. brand_code
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌code", name = "brandCode", required = false, example = "")
	private String brandCode;
	/**
	 * 只读. 线下vipid. erp_id
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线下vipid", name = "erpId", required = false, example = "")
	private String erpId;
	/**
	 * 只读. . valid
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. . remark
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. . create_user_id
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. . create_user_name
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. . create_date
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. . modified_user_id
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. . modified_user_name
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. . modified_date
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. . version
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Long getMbrEuCurrencyRecordId() {
		return mbrEuCurrencyRecordId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setMbrEuCurrencyRecordId(Long mbrEuCurrencyRecordId) {
		this.mbrEuCurrencyRecordId = mbrEuCurrencyRecordId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public BigDecimal getTotalAmount() {
		return totalAmount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setTotalAmount(BigDecimal totalAmount) {
		this.totalAmount = totalAmount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public BigDecimal getAmount() {
		return amount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public String getOrderNo() {
		return orderNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setOrderNo(String orderNo) {
		this.orderNo = orderNo == null ? null : orderNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Date getPlaceOrderTime() {
		return placeOrderTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setPlaceOrderTime(Date placeOrderTime) {
		this.placeOrderTime = placeOrderTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Date getOfflineUpdateDate() {
		return offlineUpdateDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setOfflineUpdateDate(Date offlineUpdateDate) {
		this.offlineUpdateDate = offlineUpdateDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public String getOfflineCompanyCode() {
		return offlineCompanyCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setOfflineCompanyCode(String offlineCompanyCode) {
		this.offlineCompanyCode = offlineCompanyCode == null ? null : offlineCompanyCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public String getBrandCode() {
		return brandCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setBrandCode(String brandCode) {
		this.brandCode = brandCode == null ? null : brandCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public String getErpId() {
		return erpId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setErpId(String erpId) {
		this.erpId = erpId == null ? null : erpId.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-02-27 13:51:31
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}
}

==> members-facade-1.0.2-20190816.105104-237-sources.jar: com/bizvane/members/facade/models/po/MbrEuCurrencyRecordPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

public class MbrEuCurrencyRecordPO implements Serializable {

	/**
	 * 只读. 主键id 自增. mbr_eu_currency_record_id
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "主键id 自增", name = "mbrEuCurrencyRecordId", required = false, example = "")
	private Long mbrEuCurrencyRecordId;
	/**
	 * 只读. 企业id. sys_company_id
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. 品牌id. brand_id
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. 会员code. member_code
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "会员code", name = "memberCode", required = false, example = "")
	private String memberCode;
	/**
	 * 只读. 北欧币余额. total_amount
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "北欧币余额", name = "totalAmount", required = false, example = "")
	private BigDecimal totalAmount;
	/**
	 * 只读. 流水数目. amount
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "流水数目", name = "amount", required = false, example = "")
	private BigDecimal amount;
	/**
	 * 只读. 订单号. order_no
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "订单号", name = "orderNo", required = false, example = "")
	private String orderNo;
	/**
	 * 只读. 下单时间. place_order_time
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "下单时间", name = "placeOrderTime", required = false, example = "")
	private Date placeOrderTime;
	/**
	 * 只读. 线下更新时间. offline_update_date
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线下更新时间", name = "offlineUpdateDate", required = false, example = "")
	private Date offlineUpdateDate;
	/**
	 * 只读. . offline_company_code
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "offlineCompanyCode", required = false, example = "")
	private String offlineCompanyCode;
	/**
	 * 只读. 品牌code. brand_code
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "品牌code", name = "brandCode", required = false, example = "")
	private String brandCode;
	/**
	 * 只读. 线下vipid. erp_id
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "线下vipid", name = "erpId", required = false, example = "")
	private String erpId;
	/**
	 * 只读. 店铺名称. store_name
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "店铺名称", name = "storeName", required = false, example = "")
	private String storeName;
	/**
	 * 只读. . valid
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. . remark
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. . create_user_id
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. . create_user_name
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. . create_date
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. . modified_user_id
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. . modified_user_name
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. . modified_date
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. . version
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Long getMbrEuCurrencyRecordId() {
		return mbrEuCurrencyRecordId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setMbrEuCurrencyRecordId(Long mbrEuCurrencyRecordId) {
		this.mbrEuCurrencyRecordId = mbrEuCurrencyRecordId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getMemberCode() {
		return memberCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode == null ? null : memberCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public BigDecimal getTotalAmount() {
		return totalAmount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setTotalAmount(BigDecimal totalAmount) {
		this.totalAmount = totalAmount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public BigDecimal getAmount() {
		return amount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setAmount(BigDecimal amount) {
		this.amount = amount;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getOrderNo() {
		return orderNo;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setOrderNo(String orderNo) {
		this.orderNo = orderNo == null ? null : orderNo.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Date getPlaceOrderTime() {
		return placeOrderTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setPlaceOrderTime(Date placeOrderTime) {
		this.placeOrderTime = placeOrderTime;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Date getOfflineUpdateDate() {
		return offlineUpdateDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setOfflineUpdateDate(Date offlineUpdateDate) {
		this.offlineUpdateDate = offlineUpdateDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getOfflineCompanyCode() {
		return offlineCompanyCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setOfflineCompanyCode(String offlineCompanyCode) {
		this.offlineCompanyCode = offlineCompanyCode == null ? null : offlineCompanyCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getBrandCode() {
		return brandCode;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setBrandCode(String brandCode) {
		this.brandCode = brandCode == null ? null : brandCode.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getErpId() {
		return erpId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setErpId(String erpId) {
		this.erpId = erpId == null ? null : erpId.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getStoreName() {
		return storeName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setStoreName(String storeName) {
		this.storeName = storeName == null ? null : storeName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-04-15 15:19:40
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}
}
